:icon: material/toggle-switch

Control
=======

The control commands are a set of simple utilities to activate or deactivate
certain components of an instrument.

.. toctree::
    :maxdepth: 1

    shutdown_geocom
    shutdown_gsidna
    startup_geocom
    startup_gsidna
